const countries_data = [
    {
        "Country": "USA",
        "GDP": 13,
        "Population": 330,
        "GDP Growth Rate": 5.9
    },
    {
        "Country": "Germany",
        "GDP": 4,
        "Population": 83,
        "GDP Growth Rate": 2.6
    },
    {
        "Country": "Russia",
        "GDP": 2.2,
        "Population": 144,
        "GDP Growth Rate": 4.7
    },
    {
        "Country": "Japan",
        "GDP": 4.2,
        "Population": 124,
        "GDP Growth Rate": 1.7
    },
    {
        "Country": "France",
        "GDP": 2.7,
        "Population": 64,
        "GDP Growth Rate": 6.8
    }
];

// console.log(countries_data) // show how data attributes look
d3.map(countries_data, (d) => console.log(d.Country))

const width = 800, height = 400;
const margin = { top: 20, bottom: 50, right: 20, left: 80 };

// axes data
const X = d3.map(countries_data, d => d.Country);
const Y = d3.map(countries_data, d => d.Population);

// set domain and range for x and y scales
const XDomain = X;
const YDomain = [0, 400]; // can use Math.max(...Y)

const XRange = [margin.left, width - margin.right];
const YRange = [height - margin.bottom, margin.top];

const XScale = d3.scaleBand(XDomain, XRange).padding(0.1);
const YScale = d3.scaleLinear(YDomain, YRange); // [d3-scales] https://d3js.org/d3-scale#axis

// create axes
const XAxis = d3.axisBottom(XScale); // https://d3js.org/d3-axis#axis
const YAxis = d3.axisLeft(YScale);

const svgBar = d3.select("#chart2")
    .append("svg") // single element that will contain the joined HTML/SVG elements
    .attr("width", width) // describes the type of element we are joining
    .attr("height", height)

svgBar.append("g")
    .attr("transform", `translate(0,${height - margin.bottom})`)
    .call(XAxis);

svgBar.append("g")
    .attr("transform", `translate(${margin.left},0)`)
    .call(YAxis);

// // bars

svgBar.append("g")
    .selectAll("rect")
    .data(countries_data)
    .join("rect")
    .attr("x", (d, i) => XScale(X[i]))
    .attr("y", (d, i) => YScale(Y[i]))
    .attr("height", (d, i) => YScale(0) - YScale(Y[i]))
    // attr("height", (d, i) => YScale(Y[i])) // defining height wrt to top of svg element
    .attr("width", XScale.bandwidth())
    .attr("fill", "#00796b");

// axes labels

svgBar.append("text")
    .attr("class", "x-axis-label")
    .attr("x", width/2)
    .attr("y", height - 10)
    .text("Countries")

svgBar.append("text")
    // .attr("class", "y-axis-label")
    .attr("transform", "rotate(-90)")
    .attr("x", -height/2)
    .attr("y", 30)
    .text("Population (million)")

svgBar.append("text")
    .attr("class", "chart-title")
    .attr("text-anchor", "middle")
    .attr("x", width/2)
    .attr("y", 20)
    .text("Countries and their Populations");


